# ODA Component Package

This project is in format of a Component Package. Component Packages are the
recommended way to organize Oracle Digital Assistant Custom Components and Event Handler code and allow the
component code to be more portable to different runtime environments.

> Generated by `{{sdkName}}` on **{{date}}**

## Structure

```text
.
├── .npmignore
├── src
│   └── main.ts
│   └── components
│       └── ...
├── package.json
├── Dockerfile
├── docker-compose.yml
├── tsconfig.json
└── spec
    └── ...
```

| | Description |
|--|--|
| `.npmignore` | Ignore files when packaging as `npm` module |
| `src` | Root directory for typescript files |
| `src/components` | Directory _(default)_ where typescript Component implementations are added |
| `src/main.ts` | Entrypoint for the typescript Component Package configuration |
| `tsconfig.json` | Typescript configuration settings |
| `Dockerfile` | Configuration file to create docker image |
| `docker-compose.yml` | Configuration file for docker deployment |
| `spec` | Placeholder for unit test implementations |

The Component Package behaves like any other `npm` project. Directly install
any dependencies or tools required to implement the customizations.

## Development

All typescript files under the `src` directory are transpiled into javascript files in the build directory. Transpiling happens automatically when you start the service using `npm start` or when you package the service using `npm pack`. If you want transpilation to happen every time you make a change to a typescript file, you can run `npm run-script watch`.

> **TIP:** Use `npm run {{sdkBin}}` for additional CLI help and usage information.

This component package is ready to run as a local development service. Once the
service starts you may use a local tunnel, such as [`ngrok`](https://ngrok.com/),
and configure an _External_ Service to connect the components to your Skill.

```shell
npm start
# or run with additional options
npm run {{sdkBin}} -- service .
# or run with debugger
node --inspect $(npm bin)/{{sdkBin}} service .
```

With custom component services running, test endpoints like so:

```shell
# get component metadata
curl -X GET localhost:3000/components

# invoke custom component
curl -H "Content-Type: application/json" -d @./spec/test.cc.req.json localhost:3000/components/{{componentName}}

# invoke entity event handler component
curl -H "Content-Type: application/json" -d @./spec/test.eh.req.json localhost:3000/components/resolveentities/{{componentName}}
```

## Deployment

As this package is designed to be installed and run with a corresponding service
wrapper, run `npm pack` and upload the resulting `.tgz` as a package for
the _Embedded Container_ service.

```shell
npm pack
# or validate and package with the {{sdkName}} command line
npm run {{sdkBin}} -- pack .
```

> **TIP:** use `npm run {{sdkBin}} -- pack --help` for additional packaging
options.

Run the following commands to deploy to docker and start the container:
```shell
npm run-script docker-build
docker-compose up
```
