import { Logger, InvocationCallback } from '../../common/definitions';
import { CustomComponentContext } from './sdk';
import { CustomComponent, CustomComponentMetadata } from './kinds';
/**
 * Custom component abstract class.
 * @preferred
 * @example export class MyCustomComponent extends ComponentAbstract { ... }
 */
export declare abstract class ComponentAbstract implements CustomComponent {
    protected readonly logger: Logger;
    constructor();
    /**
     * component metadata method.
     * @return - metadata property object for the custom component.
     */
    abstract metadata(): CustomComponentMetadata;
    /**
     * component invocation method.
     * @param conversation Instantiated Conversation instance
     * @param done Conversation done callback
     * @return void
     */
    abstract invoke(conversation: CustomComponentContext, done: InvocationCallback): void;
}
