import * as express from 'express';
import { Logger } from '../common/definitions';
export { express };
export declare type ServiceInstance = express.Router | express.Express;
export interface StaticMiddlwareAbstract {
    extend(service: ServiceInstance, options?: any): any;
    new (service: ServiceInstance, options: any): MiddlewareAbstract;
}
export interface ParsedRequest extends express.Request {
    body: any;
}
/**
 * interface for extended request object in OMCe
 * @see https://docs.oracle.com/en/cloud/paas/mobile-suite/develop/calling-apis-custom-code.html
 */
export interface MobileCloudRequest extends ParsedRequest {
    oracleMobile?: {
        [service: string]: {
            [method: string]: Function;
        };
    };
}
/**
 * Embedded middleware abstraction layer.
 */
export declare abstract class MiddlewareAbstract {
    protected options?: any;
    protected _logger: Logger;
    protected _service: ServiceInstance;
    /**
     * static getter for class constructor
     */
    private static get ctor();
    /**
     * extend static method. Instantiate the middleware class.
     * @param service: express.Router - main namespace router.
     * @param options: any - Channel specific middleware options.
     * @return instantiated class.
     */
    static extend(service: ServiceInstance, options?: any): MiddlewareAbstract;
    constructor(service: ServiceInstance, options?: any);
    /**
     * abstract _init. to be implemented by implementation classes.
     * @param service: application service router
     * @param options: any channel specific middleware options.
     */
    protected abstract _init(service: ServiceInstance, options: any): void;
}
