/// <reference types="express" />
import { ComponentListItem } from '../lib/component/registry';
import { MiddlewareAbstract, express } from './abstract';
/**
 * component middleware specific options
 */
export interface ComponentMiddlewareOptions {
    /** base url for custom component endpoints (defaults to '/') */
    baseUrl?: string;
    /** working directory of the project runtime (defaults to process.cwd()) */
    cwd?: string;
    /** list of components to register, these will be considered 'global' */
    register?: ComponentListItem[];
    /** base directory for component registry scan into collections */
    autocollect?: string;
    /** conversation mixin methods | properties */
    mixins?: any;
}
/**
 * ComponentMiddleware.
 * @extends MiddlewareAbstract
 */
export declare class ComponentMiddleware extends MiddlewareAbstract {
    protected _init(service: express.Express, options: ComponentMiddlewareOptions): void;
    /**
     * construct an endpoint from base and url
     * @param base - base url
     * @param url - endpoint url
     */
    private __endpoint;
    /**
     * get Shell methods
     * @param registry - The registry for the invocation shell
     */
    private __getShell;
    /**
     * invoke the component shell.
     * @param componentName: string - component name
     * @param registry - registry to which the component belongs
     * @param options - Middleware options reference.
     * @param req - MobileCloudRequest
     * @param res - express.Response
     */
    private __invoke;
    /**
     * convenience handler for CC invocation
     * @param res: express.Response
     */
    private __invocationCb;
}
