import { CustomComponentContext as SDK, ComponentRequestBody, MessagePayload } from '../../lib/';
/**
 * Create a mock request for component middleware handling.
 * Individual properties and variables may be specified by modifying the result.
 * @param {*} [messagePayload] - message payload
 * @param {*} [properties] - conversation properties
 * @param {*} [variables] - conversation variables
 * @param {string} [type] - channel type
 */
export declare function MockRequest(messagePayload?: {}, properties?: any, variables?: any, type?: string): ComponentRequestBody;
/**
 * Extension for the main Conversation class with testing conveniences.
 *
 * ```javascript
 * import * as Testing from '@oracle/bots-node-sdk/testing';
 * import { MyCustomComponent } from 'path/to/custom/components';
 *
 * describe('MyCustomComponent', () => {
 *   it('should reply with message', done => {
 *     const request = Testing.MockRequest();
 *     const conversation = Testing.MockConversation.fromRequest(request);
 *     new MyCustomComponent()
 *       .invoke(conversation, err => {
 *         expect(conversation.response().messages).toBeDefined();
 *         return err ? done.fail(err) : done();
 *       });
 *   })
 * })
 * ```
 */
export declare class MockConversation extends SDK {
    /**
     * create a mock conversation with an "empty" valid request.
     * @return Conversation
     */
    static any(): MockConversation;
    /**
     * create conversation instance from a request
     * @param req the component invocation request body
     * @return Conversation
     */
    static fromRequest(req: ComponentRequestBody): MockConversation;
    /**
     * get conversation reply messages
     * @return - message list returned by the component
     */
    getReplies(): MessagePayload[];
}
